<?
function graph_cpu_util ($data) { 

    $opts_DEF = rrdtool_get_def($data,"cpu");

    $limit = 100*$data["cpu_num"];
    
    $opts_GRAPH = array( 		    

        "HRULE:$limit#FF0000:",

        "AREA:cpu#00CC00:'CPU Utilization '",
        "LINE1:cpu#0000FF:''",

	"GPRINT:cpu:MAX:'Max\:%8.2lf %%'",
        "GPRINT:cpu:AVERAGE:'Average\:%8.2lf %%'",
        "GPRINT:cpu:LAST:'Last\:%8.2lf %%'"
    );

    $opts_header[] = "--vertical-label='CPU Utilization %'";
    $opts_header[] = "--rigid";
    $opts_header[] = "--upper-limit=$limit";

    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
}
?>
